@@ -1,5 +1,4 @@
-`hdr2.den` <-
-function (x = NULL, prob = c(50, 95, 99), den = NULL, h = NULL, ylab = "", ...) 
+hdr2.den <- function (x = NULL, prob = c(50, 95, 99), den = NULL, h = NULL, ylab = "", ...)
 {
     library(hdrcde)
 
